@@ -3,15 +3,17 @@
 """ automaticproperties.py
 An abstract class which creates properties for this class automatically.
 """
-__author__ = "Anthony Fong"
-__copyright__ = "Copyright 2021, Anthony Fong"
-__credits__ = ["Anthony Fong"]
-__license__ = ""
-__version__ = "1.4.3"
-__maintainer__ = "Anthony Fong"
-__email__ = ""
-__status__ = "Production/Stable"
+# Package Header #
+from ..__header__ import *
 
+# Header #
+__author__ = __author__
+__credits__ = __credits__
+__maintainer__ = __maintainer__
+__email__ = __email__
+
+
+# Imports #
 # Default Libraries #
 from abc import abstractmethod
 from builtins import property
@@ -22,8 +24,6 @@ from builtins import property
 from ..baseobject import BaseObject
 from .initmeta import InitMeta
 
-# Local Libraries #
-
 
 # Definitions #
 # Classes #
@@ -35,7 +35,7 @@ class AutomaticProperties(BaseObject, metaclass=InitMeta):
     """
     _properties_map = []
 
-    # Class Methods
+    # Class Methods #
     # Class Construction
     @classmethod
     def _init_class_(cls):
