@@ -3,15 +3,17 @@
 """ initmeta.py
 InitMeta is an abstract metaclass that implements an init class method which allows some setup after a class is created.
 """
-__author__ = "Anthony Fong"
-__copyright__ = "Copyright 2021, Anthony Fong"
-__credits__ = ["Anthony Fong"]
-__license__ = ""
-__version__ = "1.4.3"
-__maintainer__ = "Anthony Fong"
-__email__ = ""
-__status__ = "Production/Stable"
+# Package Header #
+from ..__header__ import *
 
+# Header #
+__author__ = __author__
+__credits__ = __credits__
+__maintainer__ = __maintainer__
+__email__ = __email__
+
+
+# Imports #
 # Default Libraries #
 
 # Downloaded Libraries #
@@ -25,7 +27,7 @@ from ..basemeta import BaseMeta
 class InitMeta(BaseMeta):
     """An abstract metaclass that implements an init class method which allows some setup after a class is created."""
 
-    # Magic Methods
+    # Magic Methods #
     # Construction/Destruction
     def __new__(mcs, name, bases, namespace, **kwargs):
         cls = super().__new__(mcs, name, bases, namespace, **kwargs)
