@@ -29,15 +29,17 @@ access which is not great for most applications.
 
 Todo: add magic method support for StaticWrapper and DynamicWrapper (requires thorough method resolution handling)
 """
-__author__ = "Anthony Fong"
-__copyright__ = "Copyright 2021, Anthony Fong"
-__credits__ = ["Anthony Fong"]
-__license__ = ""
-__version__ = "1.4.3"
-__maintainer__ = "Anthony Fong"
-__email__ = ""
-__status__ = "Production/Stable"
+# Package Header #
+from ..__header__ import *
 
+# Header #
+__author__ = __author__
+__credits__ = __credits__
+__maintainer__ = __maintainer__
+__email__ = __email__
+
+
+# Imports #
 # Default Libraries #
 from builtins import property
 
@@ -121,7 +123,7 @@ class StaticWrapper(BaseObject, metaclass=InitMeta):
     _exclude_attributes = {"__slotnames__"}
     _wrapped_attributes = {}
 
-    # Class Methods
+    # Class Methods #
     # Class Construction
     @classmethod
     def _init_class_(cls):
@@ -349,7 +351,7 @@ class StaticWrapper(BaseObject, metaclass=InitMeta):
         cls._unwrap()
         cls._class_wrap(objects)
 
-    # Instance Methods
+    # Instance Methods #
     # Wrapping
     def _wrap(self):
         """Adds attributes from embedded objects as properties."""
@@ -441,7 +443,7 @@ class DynamicWrapper(BaseObject):
     """
     _wrap_attributes = []
 
-    # Magic Methods
+    # Magic Methods #
     # Attribute Access
     def __getattr__(self, name):
         """Overrides the getattr magic method to get the attribute of another object if that attribute is not present.
@@ -500,7 +502,7 @@ class DynamicWrapper(BaseObject):
         # If the item is an attribute in self or not in any indirect parent set as attribute
         object.__delattr__(self, name)
 
-    # Instance Methods
+    # Instance Methods #
     # Attribute Access
     def _setattr(self, name, value):
         """An override method that will set an attribute of this object without checking its presence in other objects.
