@@ -3,15 +3,17 @@
 """ warnings.py
 Adds additional Warnings.
 """
-__author__ = "Anthony Fong"
-__copyright__ = "Copyright 2021, Anthony Fong"
-__credits__ = ["Anthony Fong"]
-__license__ = ""
-__version__ = "1.4.3"
-__maintainer__ = "Anthony Fong"
-__email__ = ""
-__status__ = "Production/Stable"
+# Package Header #
+from .__header__ import *
 
+# Header #
+__author__ = __author__
+__credits__ = __credits__
+__maintainer__ = __maintainer__
+__email__ = __email__
+
+
+# Imports #
 # Default Libraries #
 
 # Downloaded Libraries #
@@ -24,7 +26,7 @@ __status__ = "Production/Stable"
 class TimeoutWarning(Warning):
     """A general warning for timeouts."""
 
-    # Magic Methods
+    # Magic Methods #
     # Construction/Destruction
     def __init__(self, name="A function"):
         message = f"{name} timed out"
