@@ -1,22 +1,31 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 """ test_baseobjects.py
-Test for the baseobjects package
+Test for the baseobjects package.
 """
-__author__ = "Anthony Fong"
-__copyright__ = "Copyright 2021, Anthony Fong"
-__credits__ = ["Anthony Fong"]
-__license__ = ""
-__version__ = "1.4.2"
-__maintainer__ = "Anthony Fong"
-__email__ = ""
-__status__ = "Production/Stable"
+# Package Header #
+from src.baseobjects.__header__ import *
 
+# Header #
+__author__ = __author__
+__credits__ = __credits__
+__maintainer__ = __maintainer__
+__email__ = __email__
+
+
+# Imports #
 # Default Libraries #
 import abc
 import copy
+import cProfile
+import datetime
+import functools
+import io
 import pathlib
 import pickle
+import pstats
+from pstats import Stats, f8, func_std_string
+import time
 import timeit
 
 # Downloaded Libraries #
@@ -24,6 +33,7 @@ import pytest
 
 # Local Libraries #
 import src.baseobjects as baseobjects
+from src.baseobjects.cachingtools import timed_lru_cache, timed_keyless_cache_method
 
 
 # Definitions #
@@ -35,6 +45,49 @@ def tmp_dir(tmpdir):
 
 
 # Classes #
+class StatsMicro(Stats):
+    def print_stats(self, *amount):
+        for filename in self.files:
+            print(filename, file=self.stream)
+        if self.files:
+            print(file=self.stream)
+        indent = ' ' * 8
+        for func in self.top_level:
+            print(indent, func_get_function_name(func), file=self.stream)
+
+        print(indent, self.total_calls, "function calls", end=' ', file=self.stream)
+        if self.total_calls != self.prim_calls:
+            print("(%d primitive calls)" % self.prim_calls, end=' ', file=self.stream)
+        print("in %.3f microseconds" % (self.total_tt*1000000), file=self.stream)
+        print(file=self.stream)
+        width, list = self.get_print_list(amount)
+        if list:
+            self.print_title()
+            for func in list:
+                self.print_line(func)
+            print(file=self.stream)
+            print(file=self.stream)
+        return self
+
+    def print_line(self, func):  # hack: should print percentages
+        cc, nc, tt, ct, callers = self.stats[func]
+        c = str(nc)
+        if nc != cc:
+            c = c + '/' + str(cc)
+        print(c.rjust(9), end=' ', file=self.stream)
+        print(f8(tt*1000000), end=' ', file=self.stream)
+        if nc == 0:
+            print(' '*8, end=' ', file=self.stream)
+        else:
+            print(f8(tt/nc*1000000), end=' ', file=self.stream)
+        print(f8(ct*1000000), end=' ', file=self.stream)
+        if cc == 0:
+            print(' '*8, end=' ', file=self.stream)
+        else:
+            print(f8(ct/cc*1000000), end=' ', file=self.stream)
+        print(func_std_string(func), file=self.stream)
+
+
 class ClassTest(abc.ABC):
     """Default class tests that all classes should pass."""
     class_ = None
@@ -62,7 +115,7 @@ class TestInitMeta(ClassTest):
 
 
 class BaseBaseObjectTest(ClassTest):
-    """All BaseObject subclasses need to base these tests to considered functional."""
+    """All BaseObject subclasses need to pass these tests to considered functional."""
     pass
 
 
@@ -345,6 +398,181 @@ class TestDynamicWrapper(BaseWrapperTest):
         return request.param(self)
 
 
+class TestCachingObject(ClassTest):
+    class_ = baseobjects.CachingObject
+    zero_time = datetime.timedelta(0)
+
+    class CachingTestObject(baseobjects.CachingObject):
+        def __init__(self, a=1, init=True):
+            super().__init__()
+            self.a = a
+
+        @property
+        def proxy(self):
+            return self.get_proxy.caching_call()
+
+        @timed_keyless_cache_method(lifetime=2, call_method="clearing_call", collective=False)
+        def get_proxy(self):
+            return datetime.datetime.now()
+
+        def normal(self):
+            return datetime.datetime.now()
+
+        def printer(self):
+            print(self.a)
+
+    def test_lru_cache(self):
+        @timed_lru_cache(lifetime=1)
+        def add_one(number=0):
+            return number + 1
+
+        n = add_one(number=1)
+
+        assert n == 2
+
+    def test_lru_cache_original_func(self):
+        @timed_lru_cache(lifetime=1)
+        def add_one(number=0):
+            return number + 1
+
+        n = add_one.func(number=1)
+
+        assert n == 2
+
+    def test_lru_cache_switch(self):
+        @timed_lru_cache(lifetime=1)
+        def add_one(number=0):
+            return number + 1
+
+        add_one.set_call(caching=False)
+
+        n = add_one.func(number=1)
+
+        assert n == 2
+
+    def test_object_timed_cache(self):
+        cacher = TestCachingObject.CachingTestObject()
+
+        first = cacher.proxy
+        time.sleep(1)
+        second = cacher.proxy
+        time.sleep(2)
+        third = cacher.proxy
+
+        assert (second - first == self.zero_time) and (third - first != self.zero_time)
+
+    def test_object_cache_reset(self):
+        cacher = TestCachingObject.CachingTestObject()
+
+        first = cacher.proxy
+        second = cacher.get_proxy()
+        third = cacher.proxy
+
+        assert (second - first != self.zero_time) and (third - second == self.zero_time)
+
+    def test_object_cache_instances(self):
+        cacher = TestCachingObject.CachingTestObject()
+        cacher2 = TestCachingObject.CachingTestObject()
+
+        first = cacher.proxy
+        _ = cacher.proxy
+        time.sleep(1)
+        second = cacher2.proxy
+
+        assert second - first != self.zero_time
+
+    def test_cache_bypass_speed(self):
+        cacher = TestCachingObject.CachingTestObject()
+
+        def new_access():
+            cacher.get_proxy()
+
+        def old_access():
+            cacher.normal()
+
+        mean_new = timeit.timeit(new_access, number=self.timeit_runs) / self.timeit_runs * 1000000
+        mean_old = timeit.timeit(old_access, number=self.timeit_runs) / self.timeit_runs * 1000000
+        percent = (mean_new / mean_old) * 100
+
+        print(f"\nNew speed {mean_new:.3f} μs took {percent:.3f}% of the time of the old function.")
+        assert percent < self.speed_tolerance
+
+    def test_cached_speed(self):
+        cacher = TestCachingObject.CachingTestObject()
+
+        cacher.proxy
+
+        def new_access():
+            cacher.proxy
+
+        def old_access():
+            cacher.a
+
+        mean_new = timeit.timeit(new_access, number=self.timeit_runs) / self.timeit_runs * 1000000
+        mean_old = timeit.timeit(old_access, number=self.timeit_runs) / self.timeit_runs * 1000000
+        percent = (mean_new / mean_old) * 100
+
+        print(f"\nNew speed {mean_new:.3f} μs took {percent:.3f}% of the time of the old function.")
+        assert percent < self.speed_tolerance
+
+    def test_cached_profile(self):
+        cacher = TestCachingObject.CachingTestObject()
+        cacher.proxy
+
+        pr = cProfile.Profile()
+        pr.enable()
+
+        cacher.proxy
+
+        pr.disable()
+        s = io.StringIO()
+        sortby = pstats.SortKey.TIME
+        ps = StatsMicro(pr, stream=s).sort_stats(sortby)
+        ps.print_stats()
+        print(s.getvalue())
+
+    def test_functool_speed(self):
+        x = 1
+
+        @functools.lru_cache
+        def proxy(a=None):
+            return datetime.datetime.now()
+
+        proxy()
+
+        def new_access():
+            proxy()
+
+        def old_access():
+            x
+
+        mean_new = timeit.timeit(new_access, number=self.timeit_runs) / self.timeit_runs * 1000000
+        mean_old = timeit.timeit(old_access, number=self.timeit_runs) / self.timeit_runs * 1000000
+        percent = (mean_new / mean_old) * 100
+
+        print(f"\nNew speed {mean_new:.3f} μs took {percent:.3f}% of the time of the old function.")
+        assert percent < self.speed_tolerance
+
+    def test_functool_profile(self):
+        @functools.lru_cache
+        def proxy(a=None):
+            return datetime.datetime.now()
+
+        proxy()
+
+        pr = cProfile.Profile()
+        pr.enable()
+
+        proxy()
+
+        pr.disable()
+        s = io.StringIO()
+        sortby = pstats.SortKey.TIME
+        ps = StatsMicro(pr, stream=s).sort_stats(sortby)
+        ps.print_stats()
+        print(s.getvalue())
+
+
 # Main #
 if __name__ == '__main__':
     pytest.main(["-v", "-s"])
